@@ -79,7 +79,7 @@ class KiwoomOpenApiServiceClientStubCoreWrapper:
         request.original_order_no = '' if original_order_no is None else original_order_no
         return self._stub.OrderCall(request)
 
-    def RealCall(self, scrnno, codes, fids, realtype=None):
+    def RealCall(self, scrnno, codes, fids, realtype=None, infer_fids=False, readable_names=False, fast_parse=False):
         request = KiwoomOpenApiService_pb2.RealRequest()
         fids = [int(fid) for fid in fids]
         if realtype is None:
@@ -88,7 +88,17 @@ class KiwoomOpenApiServiceClientStubCoreWrapper:
         request.code_list.extend(codes) # pylint: disable=no-member
         request.fid_list.extend(fids) # pylint: disable=no-member
         request.real_type = realtype
+        request.flags.infer_fids = infer_fids # pylint: disable=no-member
+        request.flags.readable_names = readable_names # pylint: disable=no-member
+        request.flags.fast_parse = fast_parse # pylint: disable=no-member
         return self._stub.RealCall(request)
+    
+    def SetLogLevel(self, level, logger=''):
+        request = KiwoomOpenApiService_pb2.SetLogLevelRequest()
+        request.level = level
+        request.logger = logger
+        return self._stub.SetLogLevel(request)
+
 
 class KiwoomOpenApiServiceClientStubWrapper(KiwoomOpenApiServiceClientStubCoreWrapper):
 
@@ -148,7 +158,7 @@ class KiwoomOpenApiServiceClientStubWrapper(KiwoomOpenApiServiceClientStubCoreWr
           3 : ELW
           8 : ETF
           50 : KONEX
-          4 :  뮤추얼펀드
+          4 : 뮤추얼펀드
           5 : 신주인수권
           6 : 리츠
           9 : 하이얼펀드
@@ -230,11 +240,11 @@ class KiwoomOpenApiServiceClientStubWrapper(KiwoomOpenApiServiceClientStubCoreWr
         """
         [수정주가구분] 1:유상증자, 2:무상증자, 4:배당락, 8:액면분할, 16:액면병합, 32:기업합병, 64:감자, 256:권리락
         """
-        now = datetime.datetime.now()
         if start_date is None:
+            now = datetime.datetime.now()
             start_date = now
-        if now < now.replace(hour=15, minute=30):
-            start_date -= datetime.timedelta(days=1)
+            if now < now.replace(hour=15, minute=30):
+                start_date -= datetime.timedelta(days=1)
         date_format = '%Y%m%d'
         if isinstance(start_date, datetime.datetime):
             start_date = start_date.strftime(date_format)
@@ -265,11 +275,12 @@ class KiwoomOpenApiServiceClientStubWrapper(KiwoomOpenApiServiceClientStubCoreWr
             for values in response.listen_response.multi_data.values:
                 records.append(values.values)
             date_index = columns.index('일자')
-            from_date = response.listen_response.multi_data.values[0].values[date_index]
-            to_date = response.listen_response.multi_data.values[-1].values[date_index]
-            from_date = datetime.datetime.strptime(from_date, date_format)
-            to_date = datetime.datetime.strptime(to_date, date_format)
-            logging.debug('Received data from %s to %s for code %s', from_date, to_date, code)
+            if len(response.listen_response.multi_data.values) > 0:
+                from_date = response.listen_response.multi_data.values[0].values[date_index]
+                to_date = response.listen_response.multi_data.values[-1].values[date_index]
+                from_date = datetime.datetime.strptime(from_date, date_format)
+                to_date = datetime.datetime.strptime(to_date, date_format)
+                logging.debug('Received data from %s to %s for code %s', from_date, to_date, code)
         df = pd.DataFrame.from_records(records, columns=columns)
         return df
 
@@ -281,7 +292,11 @@ class KiwoomOpenApiServiceClientStubWrapper(KiwoomOpenApiServiceClientStubCoreWr
             interval = 15
         if interval is not None:
             interval = str(interval)
-        start_date = datetime.datetime.now()
+        if start_date is None:
+            now = datetime.datetime.now()
+            start_date = now
+            if now < now.replace(hour=15, minute=30):
+                start_date -= datetime.timedelta(days=1)
         date_format = '%Y%m%d%H%M%S'
         if isinstance(start_date, datetime.datetime):
             start_date = start_date.strftime(date_format)
@@ -312,11 +327,12 @@ class KiwoomOpenApiServiceClientStubWrapper(KiwoomOpenApiServiceClientStubCoreWr
             for values in response.listen_response.multi_data.values:
                 records.append(values.values)
             date_index = columns.index('체결시간')
-            from_date = response.listen_response.multi_data.values[0].values[date_index]
-            to_date = response.listen_response.multi_data.values[-1].values[date_index]
-            from_date = datetime.datetime.strptime(from_date, date_format)
-            to_date = datetime.datetime.strptime(to_date, date_format)
-            logging.debug('Received data from %s to %s for code %s', from_date, to_date, code)
+            if len(response.listen_response.multi_data.values) > 0:
+                from_date = response.listen_response.multi_data.values[0].values[date_index]
+                to_date = response.listen_response.multi_data.values[-1].values[date_index]
+                from_date = datetime.datetime.strptime(from_date, date_format)
+                to_date = datetime.datetime.strptime(to_date, date_format)
+                logging.debug('Received data from %s to %s for code %s', from_date, to_date, code)
         df = pd.DataFrame.from_records(records, columns=columns)
         return df
 
@@ -617,7 +633,7 @@ class KiwoomOpenApiServiceClientStubWrapper(KiwoomOpenApiServiceClientStubCoreWr
         _df = pd.DataFrame.from_records(records, columns=columns)
         return single_output
 
-    def ListenRealDataForCodesAsStream(self, codes=None, fids=None, scrnno=None, realtype=None):
+    def WatchRealDataForCodesAsStream(self, codes=None, fids=None, scrnno=None, realtype=None, infer_fids=False, readable_names=False, fast_parse=False):
         if codes is None:
             codes = self.GetCommonCodeList() + self.GetKosdaqCodeList()
         if fids is None:
@@ -626,5 +642,5 @@ class KiwoomOpenApiServiceClientStubWrapper(KiwoomOpenApiServiceClientStubCoreWr
             scrnno = '0001'
         if realtype is None:
             realtype = '0'
-        for response in self.RealCall(scrnno, codes, fids, realtype):
+        for response in self.RealCall(scrnno, codes, fids, realtype, infer_fids, readable_names, fast_parse):
             yield response
